pub struct IntRange {
pub start: i64,
pub end: i64,
pub step: i64,
}Expand description
A single contiguous range of integers with a step.
Fields
start: i64end: i64step: i64Implementations
Sourceimpl IntRange
impl IntRange
Sourcepub fn new(start: i64, end: i64, step: i64) -> Result<Self, ExpressionError>
pub fn new(start: i64, end: i64, step: i64) -> Result<Self, ExpressionError>
Create a range, normalizing descending ranges to ascending form.
After construction, start <= end and step > 0 always hold.