pub struct ExprType { /* private fields */ }Expand description
Implementations
Sourceimpl ExprType
impl ExprType
pub const BOOL: ExprType
pub const INT: ExprType
pub const FLOAT: ExprType
pub const STRING: ExprType
pub const PATH: ExprType
pub const RANGE_EXPR: ExprType
pub const NULLTYPE: ExprType
pub const ANY: ExprType
pub const NORETURN: ExprType
pub const T: ExprType
pub const T1: ExprType
pub const T2: ExprType
pub const T3: ExprType
Sourcepub fn params(&self) -> &[ExprType]
pub fn params(&self) -> &[ExprType]
The type parameters (e.g. element type for lists, member types for unions).
pub fn list(elem: ExprType) -> Self
pub fn union(types: Vec<ExprType>) -> Self
pub fn unresolved(constraint: ExprType) -> Self
Sourcepub fn signature(param_types: Vec<ExprType>, return_type: ExprType) -> Self
pub fn signature(param_types: Vec<ExprType>, return_type: ExprType) -> Self
Create a function signature type: (param_types) -> return_type.
Stored as params = [param0, param1, …, return_type].
Sourcepub fn sig_params(&self) -> &[ExprType]
pub fn sig_params(&self) -> &[ExprType]
Get the parameter types of a signature (all params except the last).
Sourcepub fn sig_return(&self) -> &ExprType
pub fn sig_return(&self) -> &ExprType
Get the return type of a signature (the last param).
Sourcepub fn match_call(
&self,
arg_types: &[ExprType],
) -> Option<HashMap<TypeCode, ExprType>>
pub fn match_call( &self, arg_types: &[ExprType], ) -> Option<HashMap<TypeCode, ExprType>>
Try to match a call’s argument types against this signature. Returns type variable bindings if successful, None if no match.
Sourcepub fn resolve_call(&self, arg_types: &[ExprType]) -> Option<ExprType>
pub fn resolve_call(&self, arg_types: &[ExprType]) -> Option<ExprType>
Resolve the return type of a signature given argument types. Matches args, substitutes bindings into return type.
Sourceimpl ExprType
impl ExprType
pub fn is_list(&self) -> bool
pub fn list_element_type(&self) -> Option<&ExprType>
pub fn is_symbolic(&self) -> bool
pub fn is_concrete(&self) -> bool
Sourcepub fn substitute(&self, bindings: &HashMap<TypeCode, ExprType>) -> ExprType
pub fn substitute(&self, bindings: &HashMap<TypeCode, ExprType>) -> ExprType
Substitute type variables with concrete types.